#!/usr/bin/ksh
#
# Generic PostScript
# Advanced Printing self-extracting installation script.
#
KIT_COPYRIGHT="Copyright (c) 2003 Hewlett-Packard Company"

KIT_APS=APS
KIT_LPD=LPD
KIT_MINVER="V1.0"
KIT_TYPE=$KIT_APS
KIT_PRINTER="Generic PostScript"
KIT_FILES="Generic_Level1PS.paf Generic_Level2PS.paf"

function setupInstructions {
	print "After the installation script has successfully completed, use the" >&2
	print "/usr/pd/scripts/pd_get_started script or pdprintadmin tool to create" >&2
	print "a new printer and queue." >&2
	print "" >&2
	print "For additional information refer to the Advanced Printing Software" >&2
	print "System Administration and Operation Guide." >&2
}


# Function:
#	askUser Prompt
#
# Description:
#	Prompt for a yes/no response. Default response is no.
#
# Arguments:
#	$1 Prompt Text
#
# Returns:
#	0 User entered yes
#	1 User entered no
#
function askUser {

	print "$1? <Y/N> \c" >&2
	read Response

	case "$Response" in
	[Yy])	return 0
		;;
	[Yy][Ee][Ss])
		return 0
		;;
	*)	return 1
		;;
	esac
}

# Function:
#	wrapMsg Text
#
# Description:
#	Pipe text to fold utility to make sure it will fit
#	within 80 characters.
#
# Arguments:
#	$1 Text, Message Text
#
# Returns:
#	n/a

function wrapMsg {
	print "$1" | fold -s >&2
}

# Function:
#	printLicenseAgreement
#
# Description:
#	Print license agreement
#
# Arguments:
#	None
#
# Returns:
#	Exits when the user does not agree to the terms of the license.

function PrintLicenseAgreement {

    wrapMsg "${KIT_COPYRIGHT}. All rights reserved.\n"

    msg1="                HEWLETT-PACKARD SOFTWARE PRODUCT"
    msg2="                  \"AS IS\" WARRANTY STATEMENT"
    wrapMsg "$msg1\n$msg2\n"

    msg1="DISCLAIMER. TO THE EXTENT ALLOWED BY LOCAL LAW, THIS HP SOFTWARE"
    msg2="PRODUCT (\"SOFTWARE\") IS PROVIDED TO YOU \"AS IS\" WITHOUT WARRANTIES OR"
    msg4="CONDITIONS OF ANY KIND, WHETHER ORAL OR WRITTEN, EXPRESS OR IMPLIED."
    msg5="HP SPECIFICALLY DISCLAIMS ANY IMPLIED WARRANTIES OR CONDITIONS OF"
    msg6="MERCHANTABILITY, SATISFACTORY QUALITY, NON-INFRINGEMENT AND FITNESS"
    msg7="FOR A PARTICULAR PURPOSE. Some countries, states and provinces do not"
    msg8="allow exclusions of implied warranties or conditions, so the above"
    msg9="exclusion may not apply to you. You may have other rights that vary"
    msg10="from country to country, state to state, or province to province."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 \n"

    msg1="LIMITATION OF LIABILITY. EXCEPT TO THE EXTENT PROHIBITED BY LOCAL LAW,"
    msg2="IN NO EVENT WILL HP OR ITS SUBSIDIARIES, AFFILIATES OR SUPPLIERS BE"
    msg3="LIABLE FOR DIRECT, SPECIAL, INCIDENTAL, CONSEQUENTIAL OR OTHER DAMAGES"
    msg4="(INCLUDING LOST PROFIT, LOST DATA, OR DOWNTIME COSTS), ARISING OUT OF"
    msg5="THE USE, INABILITY TO USE, OR THE RESULTS OF USE OF THE SOFTWARE,"
    msg6="WHETHER BASED IN WARRANTY, CONTRACT, TORT OR OTHER LEGAL THEORY, AND"
    msg7="WHETHER OR NOT ADVISED OF THE POSSIBILITY OF SUCH DAMAGES. Your use of"
    msg8="the Software is entirely at your own risk. Should the Software prove"
    msg9="defective, you assume the entire cost of all service, repair or"
    msg10="correction. Some countries, states and provinces do not allow the"
    msg11="exclusion or limitation of liability for incidental or consequential"
    msg12="damages, so the above limitation may not apply to you."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 $msg5 $msg6 $msg7 $msg8 $msg9 $msg10 $msg11 $msg12 \n"

    msg1="NOTE. EXCEPT TO THE EXTENT ALLOWED BY LOCAL LAW, THESE WARRANTY TERMS"
    msg2="DO NOT EXCLUDE, RESTRICT OR MODIFY, AND ARE IN ADDITION TO, THE"
    msg3="MANDATORY STATUTORY RIGHTS APPLICABLE TO THE LICENSE OF THE SOFTWARE"
    msg4="TO YOU."
    wrapMsg "$msg1 $msg2 $msg3 $msg4 \n"

}

# Function:
#	fileVersionTest Version PathFilename
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 Version, The version of the file in this script
#	$2 PathFilename, path/filename of file to test
#
# Returns:
#	0 Script file older than installed file
#	1 Script file the same as installed file
#	2 Script file newier than install file
#
function fileVersionTest {

	new_ver=$(fixVersion $1)

	base=$(basename $2)
	ext=$(basename $2 | cut -f2 -d'.')
	case $ext in
	lpd)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	paf)
		# Version format: APX-1-001 or 100
		old_ver=$(grep 'paf-x-file-version' $2 | cut -f2 -d\= )
		;;
	pcf)
		# Version format: 1.1.2.4
		old_ver=$(grep 'Revision:' $2 | cut -f4 -d\$ | cut -f2 -d: )
		;;
	pfo)
		# The version is not provided in all the files.
		# Version format: 1.0
		old_ver=$(grep 'FileVersion' $2 | cut -f2 -d\: )
		[[ -z $old_ver ]] && old_ver="0.0"
		;;
	[rp]pd)
		# Version format: "1.0"
		old_ver=$(grep '\*FileVersion' $2 | cut -f2 -d\: )
		;;
	*)
		# Lpd print filter?
		old_ver=$(what $2 | tr -s '@' '\n' | grep $base | grep 'Revision:' | cut -f4 -d\$ | cut -f2 -d: )
		;;
	esac

	old_ver=$(fixVersion $old_ver)

	# Are the versions the same?
	if [[ $new_ver = $old_ver ]] 
	then	# Yes
		return 1
	fi

	if [[ $new_ver > $old_ver ]]
	then
		# New file more current
		return 2
	else
		# System file more current
		return 0
	fi
}

# Function:
#	checkSumTest PathFilename CheckSum1 CheckSum2
#
# Description:
#	Fetch and compare the file version.
#
# Arguments:
#	$1 PathFilename, path/filename
#	$2 CheckSum1,  First checksum value generated from the 'sum' command.
#	$3 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Checksum matched
#	1 Checksum error
#
function checkSumTest {

	sum1=`sum $1 | tr -s "  " " " | cut -f 1 -d ' '`
	sum2=`sum $1 | tr -s "  " " " | cut -f 2 -d ' '`

	if [[ $sum1 -ne $2 ]] || [[ $sum2 -ne $3 ]]
	then
		return 1
	else
		return 0
	fi
}

# Function:
#	installTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test to see if the directory exists and the file
#	uuencoded file is newier than the system file.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
function installTest {
	mkdir=0

	# Can't install the file if the directory doesn't exist.

	file_name=`basename $2`
	directory=`dirname $2`

	if [[ ! -d $directory ]]
	then
		if [[ $mkdir = 0 ]]
		then
			msg1="Error: File $file_name not installed because"
			msg2="directory $directory doesn't exist."
			wrapMsg "$msg1 $msg2"
			return 1
		else
			mkdir $directory
			chmod 755 $directory
			chown root:system $directory
		fi
	fi

	# If the file does not exist, it's ok to install.
	if [[ ! -e $2 ]]
	then
		return 0
	fi

	fileVersionTest $1 $2
	status=$?

	if [[ $status = 1 ]]
	then
		checkSumTest $2 $3 $4
		if [[ $? = 0 ]]
		then
			# Files are the same, don't install
			wrapMsg "The $file_name system file is current and will not be replaced.\n"
			return 1
		else
			# Versions are the same, but the files are different!
			print "Warning: File versions match but the files are different!">&2
			askUser "Replace $file_name"
			return $?
		fi
	fi

	if [[ $status = 0 ]]
	then
		wrapMsg "The $file_name system file is newier and will not be replaced.\n"
		return 1
 	fi

	return 0
}

# Function:
#	mimimumVersionTest version
#
# Description:
#	Test to see if the minimum application or operating version 
#	requirement is met.
#
# Arguments:
#	$1 Version,    Minimum install version requirement
#
# Returns:
#	0 test passed
#	1 test failed
#
function mimimumVersionTest {

	if [[ $KIT_TYPE = $KIT_APS ]]
	then
		# At this time there isn't a minimum APS requirement.
		return 0 
	fi

	# The only other kit type is LPD, so check the OS version.

	# Note: The version field moves 1 position between Digital UNIX
	#       and Compaq Tru64 UNIX, but is always before (Rev.
	temp=` strings /vmunix | grep '(Rev.' | grep UNIX | cut -f1 -d '(' `

	# The version is the last value
	for x in $temp
	{
	  osver=$x
	}

	# A field test version of the OS might not start with a V. At some
	# point we might need to note the difference, but for now we don't.
	# Modify the version string by replacing the first character with a V.

	temp=$osver
	osver="V$( echo "$osver" | cut -c2- )"

	if [[ $osver < $1 ]]
	then
		return 1
	fi

	return 0
}

# Function:
#	installLpdTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	If the file does not currently exist and the minimal install
#	requirements are met, a success status is returned.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Exits:
#	Exit if the minimum OS requirement is not met.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#
function installLpdTest {

	file_name=`basename $2`
	file_ext=`print "$file_name" | cut -f2 -d'.'`

	# Perform the OS test after this test. No reason to complain
	# about the os version if the file isn't going to be installed.
	if [[ $file_ext = "lpd" ]]
	then
		# If this is a .lpd file and the base directory doesn't exist
		# return.
		if [[ ! -d `dirname $2` ]]
		then
			msg1="File $file_name is not required for this version of Tru64 UNIX.\n"
			wrapMsg "$msg1"
			return 1
		fi
	fi

	installTest $1 $2 $3 $4
	return $?
}


# Function:
#	installApsTest FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Test the minimal install requirements for an APS file. 
#
# Arguments:
#	$1 File version, File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file, all tests passed
#	1 Don't install file, one or more tests failed
#

function installApsTest {

	installTest $1 $2 $3 $4
	return $?
}

# Function:
#	fixVersion Version
#
# Description:
#	Remove unwanted characters.
#	Aps two version formats are converted to a common format.
#
# Arguments:
#	$1 Version, Version string
#
# Returns:
#	The updated version string.
#
function fixVersion {

	# Remove quotes, tabs, and spaces
	ver=$(echo $1 | tr -d "\"\t ")

	# Set null strings to version 0
	if [[ -z $ver ]]
	then
		ver=0
	fi

	# If the version starts with 'a', convert
	# a???-x-xxx to xxxx
	case $ver in
	[Aa]*)	;;
	[0123456789]*)
		# Return the version
		print "$ver"
		return
		;;
	*)	# Don't know what we found so return a version of 0.
		print "0.0"
		;;
	esac

	# To compare version 100 to apx-?-??? convert
	# apx-1-001 to 1001
	# apx-1-2   to 1002
	part1=$(echo "$ver" | cut -f2 -d\-)
	part2=$(echo "$ver" | cut -f3 -d\-)

	ver=$(printf "%s%.3d" $part1 $part2)

	# Return the version
	print "$ver"
	return
}

# Function:
#	preInstall FileVersion PathFilename CheckSum1 CheckSum2
#
# Description:
#	Determine if this is an APS or LPD install and call the
#	appropriate function.
#
# Arguments:
#	$1 FileVersion,  File version
#	$2 PathFilename, path/filename
#	$3 CheckSum1,  First checksum value generated from the 'sum' command.
#	$4 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	0 Install file
#	1 Don't install file
#
function preInstall {

	status=1

	if [[ $KIT_TYPE = $KIT_LPD ]] 
	then
		installLpdTest $1 $2 $3 $4
		status=$?
	fi

	if [[ $KIT_TYPE = $KIT_APS ]] 
	then
		installApsTest $1 $2 $3 $4
		status=$?
	fi

	# On install status, backup existing file
	# if it exists
	if [[ $status = 0 ]]
	then
		if [[ -e $2 ]]
		then
			# format = filename_yyyymmmdd_hh:mm:ss
			backup=$2_$(date +"b%d_%T")
			mv $2 $backup
			wrapMsg "Backup file $backup created."

			# Return the name of the backup file
			print "$backup"
		fi
	fi
	return $status
}

# Function:
#	postInstall BackupFile Owner Group Protection FileName CheckSum1 CheckSum2
#
# Description:
#	After the file has been installed verify the file checksum. If
#	the checksum is ok, set the file owner and protection.
#
#	Notify the user of a checksum error and prompt to remove the file.
#
# Arguments:
#	$1 BackupFile, Name of the backup file
#	$2 Owner,      File owner for chown command
#	$3 Group,      Group owner for chgrp command
#	$4 Protection, File protections number, eg 644, for chmod command
#	$5 FileName,   Installed file path/filename
#	$6 CheckSum1,  First checksum value generated from the 'sum' command.
#	$7 CheckSum2,  Second checksum value generated from the 'sum' command.
#
# Returns:
#	None
#
function postInstall {

	chown $2:$3 $5
	chmod $4 $5

	checkSumTest $5 $6 $7
	if [[ $? != 0 ]]
	then
		wrapMsg "Install checksum error on file $5!"

		if [[ ! -z $1 ]]
		then
			askUser "Restore the backup file"
		else
			askUser "Delete the file $5"
		fi

		if [[ $? = 0 ]]
		then 
			rm $5
			if [[ ! -z $1 ]]
			then
				mv $1 $5
				wrapMsg "Backup file restored.\n"
			else
				wrapMsg "File $5 deleted.\n"
			fi
		fi
	else
		wrapMsg "File $5 installed.\n"
		FileInstalled=1
	fi
	return
}

# Function:
#	doHelp
#
# Description:
#	Display the install script options.
#
# Arguments:
#	None
#
# Returns:
#	None
#
function doHelp {
	print "Synopsis: $(basename $0) -option" >&2
	print "" >&2
	print "Options:  -i Install files" >&2
	print "          -p Printer configuration instructions" >&2
	print "" >&2
	return
}

#
# Program
#

typeset -xi FileInstalled=0

# Identify the program

if [[ $KIT_TYPE = $KIT_LPD ]]
then
	print "LPD \c"

elif [[ $KIT_TYPE = $KIT_APS ]]
then
	print "Advanced Printing Software \c"
fi

print "installation kit for: $KIT_PRINTER\n"


# When no arguments are provided, display the help text and exit.
if [[  $# = 0 ]]
then
	doHelp
	exit 0
fi

while getopts :hip opt
do
        case $opt in
	h)	doHelp
		exit 0
		;;
	i)	# Install, fall out of case statement
		;;
	p)	# Print post-install setup instructions
		setupInstructions
		exit 0
		;;
	\?)	doHelp
		exit 0
                ;;
        esac
done

UserName=`whoami`

if [[ $UserName != "root" ]]
then
	print "You must be root to run this program."
	exit 1
fi

mimimumVersionTest $KIT_MINVER
if [[ $? != 0 ]]
then
	msg1="This installation requires a minimum"
	msg2="operating system version of $1."
	wrapMsg "$msg1 $msg2"
	exit 1
fi

subset_name=UNKNOWN
if [[ $KIT_TYPE = $KIT_LPD ]]
then
	subset_name=OSFPRINT
elif [[ $KIT_TYPE = $KIT_APS ]]
then
	subset_name=APXBASE
else
	print "Error: Unknown kit type."
	exit 1
fi

if [ ! -e /usr/.smdb./$subset_name*.lk ]
then
	print "The update requires the $subset_name subset to be installed."
	exit 1
fi

print "This kit contains the following files:\n"

echo "$KIT_FILES" | fold -s
print ""

PRESS_ENTER='Press ENTER to continue'

printf "$PRESS_ENTER"
read temp

PrintLicenseAgreement 2>&1 | pg -e -p "$PRESS_ENTER" >&2

askUser "Do you accept the terms in the license agreement"
if [[ $? != 0 ]]
then
	# User did not accept license agreement.
	print "No files were installed."
	exit 1
fi
print "\n\n"

#--- uuencoded files ---
backup_file=$(preInstall "APX-1-001" /usr/pd/share/cap/Generic_Level1PS.paf 29508 3)
if [[ $? = 0 ]]
then
uudecode << 'EndOfEncodedFile'
begin 644 /usr/pd/share/cap/Generic_Level1PS.paf
M(R`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*(R!'96YE<FEC7TQE=F5L
M,5!3+G!A9@HC"B,@0V]P>7)I9VAT(#$Y.3D@0V]M<&%Q($-O;7!U=&5R($-O
M<G!O<F%T:6]N+B`@06QL(%)I9VAT<R!297-E<G9E9"X*(PHC($%D=F%N8V5D
M(%!R:6YT:6YG(%-O9G1W87)E(%!R:6YT97(@071T<FEB=71E($9I;&4@9F]R
M(&$@<VEM<&QE(`HC($QE=F5L(#$@4&]S=%-C<FEP="!P<FEN=&5R+@HC"B,@
M0"@C*4=E;F5R:6-?3&5V96PQ4%,N<&%F"3$N,2`Q,2\Q,B\Y.0HC"B,@5&AI
M<R!F:6QE(&ES('-U<'!L:65D('1O(&%L;&]W('!R:6YT:6YG('1O('!R:6YT
M97(@9&5V:6-E<R!T:&%T(&%R92`*(R!N;W0@<W5P<&]R=&5D(&)Y($%D=F%N
M8V5D(%!R:6YT:6YG(%-O9G1W87)E+B`@270@:7,@:6YT96YD960@=&\@"B,@
M<')O=FED92!B87-I8R!P<FEN=&EN9R!F;W(@82!B<F]A9"!C;&%S<R!O9B!D
M97-K=&]P(&%N9"!D97!A<G1M96YT86P@"B,@<')I;G1E<G,@=VAE;B!C;VYN
M96-T960@=&AR;W5G:"!S97)I86PL('!A<F%L;&5L+"!O<B!R87<@<V]C:V5T
M(`HC(&-O;FYE8W1I;VYS+B`@270@;6EG:'0@;F]T('=O<FL@9F]R(&%L;"!S
M=6-H('!R:6YT97)S+B`*(PHC($EM<&]R=&%N="!.;W1E<SH*(PHC("T@0V]M
M<&%Q(&1O97,@;F]T('-U<'!O<G0@<')I;G1E<B!A='1R:6)U=&4@9FEL97,@
M9&5R:79E9"!F<F]M(`HC("`@=&AI<R!F:6QE+@HC"B,@+2!!='1R:6)U=&5S
M(&)E9VEN;FEN9R!W:71H(")P868M(B!P<F5F:7@@87)E(&YO="!S=7!P;W)T
M960@"B,@("!A='1R:6)U=&5S+"!A;F0@=&AE:7(@8F5H879I;W(@86YD+V]R
M('!R97-E;F-E(&EN(&9U='5R92`*(R`@(')E;&5A<V5S(&]F($%D=F%N8V5D
M(%!R:6YT:6YG(%-O9G1W87)E(&ES('-U8FIE8W0@=&\@8VAA;F=E(`HC("`@
M=VET:&]U="!N;W1I8V4N"B,*(R!0;W-T4V-R:7!T(&ES(&$@=')A9&5M87)K
M(&]F($%D;V)E(%-Y<W1E;7,@26YC;W)P;W)A=&5D+@HC"B,@+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM"@IP<FEN=&5R+6UO9&5L/2)0;W-T4V-R:7!T
M(%!R:6YT97(B"F1E<V-R:7!T;W(](E5N<W5P<&]R=&5D($QE=F5L(#$@4&]S
M=%-C<FEP="!P<FEN=&5R(@H*<&%F+7@M9FEL92UN86UE/2)'96YE<FEC7TQE
M=F5L,5!3+G!A9B(*<&%F+7@M9FEL92UV97)S:6]N/2)!4%@M,2TP,#$B"@HC
M("A.;W1E.B!P<FEN=&EN9R!S:6UP;&4M=&5X="!D;V-U;65N=',@<F5Q=6ER
M97,@=&AA="!T:&4@<W5P97)V:7-O<B`*(R!B92!S970@=7`@=VET:"!A('-U
M:71A8FQE('1R86YS;&%T:6]N(&9I;'1E<BP@<W5C:"!A<R!T<FY?=&5X='!S
M*2X*"FYA=&EV92UD;V-U;65N="UF;W)M871S+7)E861Y/2)0;W-T4V-R:7!T
M(@ID;V-U;65N="UF;W)M871S+7-U<'!O<G1E9#TB4&]S=%-C<FEP="(@(G-I
M;7!L92UT97AT(@ID;V-U;65N="UF;W)M871S+7)E861Y/2)0;W-T4V-R:7!T
M(B`B<VEM<&QE+71E>'0B"@IP;&5X97,M<W5P<&]R=&5D/2)S:6UP;&5X(@IS
M:61E<RUS=7!P;W)T960](C$B"G-I9&5S+7)E861Y/2(Q(@H*:6YP=70M=')A
M>7,M<W5P<&]R=&5D/2)M86EN(@II;G!U="UT<F%Y<RUR96%D>3TB;6%I;B(*
M"F]U='!U="UB:6YS+7-U<'!O<G1E9#TB=&]P(@IO=71P=70M8FEN<RUR96%D
M>3TB=&]P(@H*(R!3=7!E<G9I<V]R(&%T=')I8G5T97,*"G!A9BUN871I=F4M
M9&]C=6UE;G0M9F]R;6%T+3$](E!O<W138W)I<'0B"G!A9BUD969A=6QT+61O
M8W5M96YT+69O<FUA=#TB4&]S=%-C<FEP="(*<&%F+6IO8BUS97!A<F%T;W(M
M9F]R;6%T/2)0;W-T4V-R:7!T(@H*(R!#;VYN96-T:6]N+7)E;&%T960@871T
M<FEB=71E<PH*<&%F+6-O;FYE8W1I;VXM;&5V96PM<V5R:6%L/3$*<&%F+6-O
M;FYE8W1I;VXM;&5V96PM:7`M<V]C:V5T/3$*<&%F+6-O;FYE8W1I;VXM;&5V
M96PM<&%R86QL96P],@H*(R!);G!U="!T<F%Y('-E;&5C=&EO;B!C;VUM86YD
M<PH*(R`H;F]N92D*"B,@3W5T<'5T(&)I;B!S96QE8W1I;VX*"B,@*&YO;F4I
M"@HC(%-I9&5S('-E;&5C=&EO;@H*<&%F+7-E="US:6UP;&5X+6-O;6UA;F0M
M,3TB('-T871U<V1I8W0@+V1U<&QE>&UO9&4@:VYO=VX@>R!F86QS92!S=&%T
M=7-D:6-T("]S971D=7!L97AM;V1E(&=E="!E>&5C(&9A;'-E('-T871U<V1I
M8W0@+W-E='1U;6)L92!G970@97AE8R!](&EF("(*<&%F+7-E="UD=7!L97@M
M8V]M;6%N9"TQ/2(@<W1A='5S9&EC="`O9'5P;&5X;6]D92!K;F]W;B![('1R
M=64@<W1A='5S9&EC="`O<V5T9'5P;&5X;6]D92!G970@97AE8R!F86QS92!S
M=&%T=7-D:6-T("]S971T=6UB;&4@9V5T(&5X96,@?2!I9B`B"G!A9BUS970M
M='5M8FQE+6-O;6UA;F0M,3TB('-T871U<V1I8W0@+V1U<&QE>&UO9&4@:VYO
M=VX@>R!T<G5E('-T871U<V1I8W0@+W-E=&1U<&QE>&UO9&4@9V5T(&5X96,@
M=')U92!S=&%T=7-D:6-T("]S971T=6UB;&4@9V5T(&5X96,@?2!I9B`B"@HC
%(&5N9`IS
`
end
EndOfEncodedFile
postInstall "$backup_file" bin bin 644 /usr/pd/share/cap/Generic_Level1PS.paf 29508 3
fi

backup_file=$(preInstall "APX-1-001" /usr/pd/share/cap/Generic_Level2PS.paf 58623 4)
if [[ $? = 0 ]]
then
uudecode << 'EndOfEncodedFile'
begin 644 /usr/pd/share/cap/Generic_Level2PS.paf
M(R`M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2T*(R!'96YE<FEC7TQE=F5L
M,E!3+G!A9@HC"B,@0V]P>7)I9VAT(#$Y.3D@0V]M<&%Q($-O;7!U=&5R($-O
M<G!O<F%T:6]N+B`@06QL(%)I9VAT<R!297-E<G9E9"X*(PHC($%D=F%N8V5D
M(%!R:6YT:6YG(%-O9G1W87)E(%!R:6YT97(@071T<FEB=71E($9I;&4@9F]R
M(&$@<VEM<&QE(`HC($QE=F5L(#(@4&]S=%-C<FEP="!P<FEN=&5R+@HC"B,@
M0"@C*4=E;F5R:6-?3&5V96PR4%,N<&%F"3$N,2`Q,2\Q,B\Y.0HC"B,@5&AI
M<R!F:6QE(&ES('-U<'!L:65D('1O(&%L;&]W('!R:6YT:6YG('1O('!R:6YT
M97(@9&5V:6-E<R!T:&%T(&%R92`*(R!N;W0@<W5P<&]R=&5D(&)Y($%D=F%N
M8V5D(%!R:6YT:6YG(%-O9G1W87)E+B`@270@:7,@:6YT96YD960@=&\@"B,@
M<')O=FED92!B87-I8R!P<FEN=&EN9R!F;W(@82!B<F]A9"!C;&%S<R!O9B!D
M97-K=&]P(&%N9"!D97!A<G1M96YT86P@"B,@<')I;G1E<G,@=VAE;B!C;VYN
M96-T960@=&AR;W5G:"!S97)I86PL('!A<F%L;&5L+"!O<B!R87<@<V]C:V5T
M(`HC(&-O;FYE8W1I;VYS+B`@270@;6EG:'0@;F]T('=O<FL@9F]R(&%L;"!S
M=6-H('!R:6YT97)S+B`*(PHC($EM<&]R=&%N="!.;W1E<SH@"B,*(R`M($-O
M;7!A<2!D;V5S(&YO="!S=7!P;W)T('!R:6YT97(@871T<FEB=71E(&9I;&5S
M(&1E<FEV960@9G)O;2`*(R`@('1H:7,@9FEL92X*(PHC("T@071T<FEB=71E
M<R!B96=I;FYI;F<@=VET:"`B<&%F+2(@<')E9FEX(&%R92!N;W0@<W5P<&]R
M=&5D(`HC("`@871T<FEB=71E<RP@86YD('1H96ER(&)E:&%V:6]R(&%N9"]O
M<B!P<F5S96YC92!I;B!F=71U<F4@"B,@("!R96QE87-E<R!O9B!!9'9A;F-E
M9"!0<FEN=&EN9R!3;V9T=V%R92!I<R!S=6)J96-T('1O(&-H86YG92`*(R`@
M('=I=&AO=70@;F]T:6-E+@HC"B,@4&]S=%-C<FEP="!I<R!A('1R861E;6%R
M:R!O9B!!9&]B92!3>7-T96US($EN8V]R<&]R871E9"X*(PHC("TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM+2TM
M+2TM+2TM+2TM+2TM+2TM+2TM+0H*<')I;G1E<BUM;V1E;#TB4&]S=%-C<FEP
M="!0<FEN=&5R(@ID97-C<FEP=&]R/2)5;G-U<'!O<G1E9"!,979E;"`R(%!O
M<W138W)I<'0@<')I;G1E<B(*"G!A9BUX+69I;&4M;F%M93TB1V5N97)I8U],
M979E;#)04RYP868B"G!A9BUX+69I;&4M=F5R<VEO;CTB05!8+3$M,#`Q(@H*
M(R`H3F]T93H@<')I;G1I;F<@<VEM<&QE+71E>'0@9&]C=6UE;G1S(')E<75I
M<F5S('1H870@=&AE('-U<&5R=FES;W(@"B,@8F4@<V5T('5P('=I=&@@82!S
M=6ET86)L92!T<F%N<VQA=&EO;B!F:6QT97(L('-U8V@@87,@=')N7W1E>'1P
M<RDN"@IN871I=F4M9&]C=6UE;G0M9F]R;6%T<RUR96%D>3TB4&]S=%-C<FEP
M="(*9&]C=6UE;G0M9F]R;6%T<RUS=7!P;W)T960](E!O<W138W)I<'0B(")S
M:6UP;&4M=&5X="(*9&]C=6UE;G0M9F]R;6%T<RUR96%D>3TB4&]S=%-C<FEP
M="(@(G-I;7!L92UT97AT(@H*<&QE>&5S+7-U<'!O<G1E9#TB<VEM<&QE>"(*
M<VED97,M<W5P<&]R=&5D/2(Q(@IS:61E<RUR96%D>3TB,2(*"FEN<'5T+71R
M87ES+7-U<'!O<G1E9#TB;6%I;B(*:6YP=70M=')A>7,M<F5A9'D](FUA:6XB
M"@IO=71P=70M8FEN<RUS=7!P;W)T960](G1O<"(*;W5T<'5T+6)I;G,M<F5A
M9'D](G1O<"(*"B,@4W5P97)V:7-O<B!A='1R:6)U=&5S"@IP868M;F%T:79E
M+61O8W5M96YT+69O<FUA="TQ/2)0;W-T4V-R:7!T(@IP868M9&5F875L="UD
M;V-U;65N="UF;W)M870](E!O<W138W)I<'0B"G!A9BUJ;V(M<V5P87)A=&]R
M+69O<FUA=#TB4&]S=%-C<FEP="(*"B,@0V]N;F5C=&EO;BUR96QA=&5D(&%T
M=')I8G5T97,*"G!A9BUC;VYN96-T:6]N+6QE=F5L+7-E<FEA;#TQ"G!A9BUC
M;VYN96-T:6]N+6QE=F5L+6EP+7-O8VME=#TQ"G!A9BUC;VYN96-T:6]N+6QE
M=F5L+7!A<F%L;&5L/3(*"B,@26YP=70@=')A>2!S96QE8W1I;VX@8V]M;6%N
M9',*"G!A9BUB;W1T;VTM:6YP=70M8V]M;6%N9"TQ/2(B"G!A9BUE;G9E;&]P
M92UI;G!U="UC;VUM86YD+3$](B(*<&%F+6QA<F=E+6-A<&%C:71Y+6EN<'5T
M+6-O;6UA;F0M,3TB(@IP868M;6%I;BUI;G!U="UC;VUM86YD+3$](B(*<&%F
M+6UA;G5A;"UI;G!U="UC;VUM86YD+3$](B(*<&%F+6UI9&1L92UI;G!U="UC
M;VUM86YD+3$](B(*<&%F+7-I9&4M:6YP=70M8V]M;6%N9"TQ/2(B"G!A9BUT
M;W`M:6YP=70M8V]M;6%N9"TQ/2(B"@HC($]U='!U="!B:6X@<V5L96-T:6]N
M(&-O;6UA;F1S"@IP868M8F]T=&]M+6]U='!U="UC;VUM86YD+3$](B(*<&%F
M+6QA<F=E+6]U='!U="UC;VUM86YD+3$](B(*<&%F+6QE9G0M;W5T<'5T+6-O
M;6UA;F0M,3TB(@IP868M;6ED9&QE+6]U='!U="UC;VUM86YD+3$](B(*<&%F
M+7)I9VAT+6]U='!U="UC;VUM86YD+3$](B(*<&%F+7-I9&4M;W5T<'5T+6-O
M;6UA;F0M,3TB(@IP868M=&]P+6]U='!U="UC;VUM86YD+3$](B(*"B,@4VED
M97,@<V5L96-T:6]N(&-O;6UA;F1S"@IP868M<V5T+7-I;7!L97@M8V]M;6%N
M9"TQ/2(@/#P@+T1U<&QE>"!F86QS92`O5'5M8FQE(&9A;'-E(#X^('-E='!A
M9V5D979I8V4@(@IP868M<V5T+61U<&QE>"UC;VUM86YD+3$](B`\/"`O1'5P
M;&5X('1R=64@+U1U;6)L92!F86QS92`^/B!S971P86=E9&5V:6-E("(*<&%F
M+7-E="UT=6UB;&4M8V]M;6%N9"TQ/2(@/#P@+T1U<&QE>"!T<G5E("]4=6UB
M;&4@=')U92`^/B!S971P86=E9&5V:6-E("(*"B,@4V]M92!P<FEN=&5R<R!U
M<V4@=&AI<R!A;'1E<FYA=&4@<V-H96UE(&9O<B!S971T:6YG('-I9&5S(&%N
M9"!P;&5X.@H*(R!P868M<V5T+7-I;7!L97@M8V]M;6%N9"TQ/2(@,2!D:6-T
M(&1U<"`O1'5P;&5X(&9A;'-E('!U="!S971P86=E9&5V:6-E("(*(R!P868M
M<V5T+61U<&QE>"UC;VUM86YD+3$](B`Q(&1I8W0@9'5P("]$=7!L97@@=')U
M92!P=70@<V5T<&%G961E=FEC92`Q(&1I8W0@9'5P("]4=6UB;&4@9F%L<V4@
M<'5T('-E='!A9V5D979I8V4@(@HC('!A9BUS970M='5M8FQE+6-O;6UA;F0M
M,3TB(#$@9&EC="!D=7`@+T1U<&QE>"!T<G5E('!U="!S971P86=E9&5V:6-E
M(#$@9&EC="!D=7`@+U1U;6)L92!T<G5E('!U="!S971P86=E9&5V:6-E("(*
("B,@16YD+@ID
`
end
EndOfEncodedFile
postInstall "$backup_file" bin bin 644 /usr/pd/share/cap/Generic_Level2PS.paf 58623 4
fi

exit 0
